==> apache-shardingsphere-5.5.2-src.zip: apache-shardingsphere-5.5.2-src-release/mode/type/standalone/core/src/main/java/org/apache/shardingsphere/mode/manager/standalone/persist/service/StandaloneProcessPersistService.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.mode.manager.standalone.persist.service;

import org.apache.shardingsphere.infra.executor.sql.process.Process;
import org.apache.shardingsphere.infra.executor.sql.process.ProcessRegistry;
import org.apache.shardingsphere.mode.persist.service.divided.ProcessPersistService;

import java.sql.SQLException;
import java.util.Collection;

/**
 * Standalone process persist service.
 */
public final class StandaloneProcessPersistService implements ProcessPersistService {
    
    @Override
    public Collection<Process> getProcessList() {
        return ProcessRegistry.getInstance().listAll();
    }
    
    @Override
    public void killProcess(final String processId) throws SQLException {
        ProcessRegistry.getInstance().kill(processId);
    }
}

==> apache-shardingsphere-5.5.3-src.zip: apache-shardingsphere-5.5.3-src-release/mode/type/standalone/core/src/main/java/org/apache/shardingsphere/mode/manager/standalone/persist/service/StandaloneProcessPersistService.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.mode.manager.standalone.persist.service;

import org.apache.shardingsphere.infra.executor.sql.process.Process;
import org.apache.shardingsphere.infra.executor.sql.process.ProcessRegistry;
import org.apache.shardingsphere.mode.persist.service.ProcessPersistService;

import java.sql.SQLException;
import java.util.Collection;

/**
 * Standalone process persist service.
 */
public final class StandaloneProcessPersistService implements ProcessPersistService {
    
    @Override
    public Collection<Process> getProcessList() {
        return ProcessRegistry.getInstance().listAll();
    }
    
    @Override
    public void killProcess(final String processId) throws SQLException {
        ProcessRegistry.getInstance().kill(processId);
    }
}
